@@ -1,8 +1,8 @@
 from ..Typing import Union
-from ..Decorators import validate
+from ..Decorators import validate_explicit
 
 
-@validate([int, float])
+@validate_explicit([int, float])
 def sign(v: Union[int, float]) -> int:
     if v == 0:
         return 1
